@@ -1,5 +1,4 @@
 import os
-from fontTools.misc.py23 import basestring
 from fontParts.base.errors import FontPartsError
 from fontParts.base.base import dynamicProperty, InterpolationMixin
 from fontParts.base.layer import _BaseGlyphVendor
@@ -158,7 +157,7 @@ class BaseFont(
 
     # save
 
-    def save(self, path=None, showProgress=False, formatVersion=None):
+    def save(self, path=None, showProgress=False, formatVersion=None, fileStructure=None):
         """
         Save the font to **path**.
 
@@ -180,7 +179,11 @@ class BaseFont(
         the original format version of the file should be preserved.
         If there is no original format version it is implied that
         the format version is the latest version for the file
-        type as supported by the environment.
+        type as supported by the environment. **fileStructure** indicates
+        the file structure of the written ufo. The **fileStructure** can
+        either be None, 'zip' or 'package', None will use the existing file
+        strucure or the default one for unsaved font. 'package' is the default
+        file structure and 'zip' will save the font to .ufoz.
 
         .. note::
 
@@ -199,11 +202,13 @@ class BaseFont(
         if formatVersion is not None:
             formatVersion = normalizers.normalizeFileFormatVersion(
                 formatVersion)
+        if fileStructure is not None:
+            fileStructure = normalizers.normalizeFileStructure(fileStructure)
         self._save(path=path, showProgress=showProgress,
-                   formatVersion=formatVersion)
+                   formatVersion=formatVersion, fileStructure=fileStructure)
 
     def _save(self, path=None, showProgress=False,
-              formatVersion=None, **kwargs):
+              formatVersion=None, fileStructure=None, **kwargs):
         """
         This is the environment implementation of
         :meth:`BaseFont.save`. **path** will be a
@@ -331,7 +336,7 @@ class BaseFont(
         import warnings
         if format is None:
             raise ValueError("The format must be defined when generating.")
-        elif not isinstance(format, basestring):
+        elif not isinstance(format, str):
             raise TypeError("The format must be defined as a string.")
         env = {}
         for key, value in environmentOptions.items():
