@@ -366,7 +366,6 @@ class BaseFontList(list):
             >>> fonts.sortBy("magic")
         """
         from types import FunctionType
-        from fontTools.misc.py23 import basestring
         valueGetters = dict(
             familyName=_sortValue_familyName,
             styleName=_sortValue_styleName,
@@ -377,7 +376,7 @@ class BaseFontList(list):
             isProportional=_sortValue_isProportional,
             isMonospace=_sortValue_isMonospace
         )
-        if isinstance(sortOptions, basestring) or isinstance(sortOptions, FunctionType):
+        if isinstance(sortOptions, str) or isinstance(sortOptions, FunctionType):
             sortOptions = [sortOptions]
         if not isinstance(sortOptions, (list, tuple)):
             raise ValueError("sortOptions must a string, list or function.")
@@ -403,7 +402,7 @@ class BaseFontList(list):
                 elif hasattr(font.info, valueName):
                     value = getattr(font.info, valueName)
                 else:
-                    raise ValueError("Unknown sort option: %s" % repr(valueGetter))
+                    raise ValueError("Unknown sort option: %s" % repr(valueName))
                 sortable.append(value)
             sortable.append(originalIndex)
             sortable.append(font)
@@ -473,6 +472,7 @@ def _sortValue_familyName(font):
         value = ""
     return value
 
+
 def _sortValue_styleName(font):
     """
     Returns font.info.styleName.
@@ -482,6 +482,7 @@ def _sortValue_styleName(font):
         value = ""
     return value
 
+
 def _sortValue_isRoman(font):
     """
     Returns 0 if the font is roman.
@@ -492,6 +493,7 @@ def _sortValue_isRoman(font):
         return 0
     return 1
 
+
 def _sortValue_isItalic(font):
     """
     Returns 0 if the font is italic.
@@ -505,6 +507,7 @@ def _sortValue_isItalic(font):
         return 0
     return 1
 
+
 def _sortValue_widthValue(font):
     """
     Returns font.info.openTypeOS2WidthClass.
@@ -514,6 +517,7 @@ def _sortValue_widthValue(font):
         value = -1
     return value
 
+
 def _sortValue_weightValue(font):
     """
     Returns font.info.openTypeOS2WeightClass.
@@ -523,6 +527,7 @@ def _sortValue_weightValue(font):
         value = -1
     return value
 
+
 def _sortValue_isProportional(font):
     """
     Returns 0 if the font is proportional.
@@ -533,6 +538,7 @@ def _sortValue_isProportional(font):
         return 0
     return 1
 
+
 def _sortValue_isMonospace(font):
     """
     Returns 0 if the font is monospace.
